@@ -1,11 +1,10 @@
 package HTML::Mason;
-{
-  $HTML::Mason::VERSION = '1.54';
-}
+# git description: 146831c
+
 # Copyright (c) 1998-2005 by Jonathan Swartz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
-
+$HTML::Mason::VERSION = '1.55';
 use 5.006;
 
 use HTML::Mason::Interp;
@@ -17,17 +16,15 @@ sub version
 
 1;
 
+# ABSTRACT: High-performance, dynamic web site authoring system
+
 __END__
 
 =pod
 
-=head1 NAME
-
-Mason - High-performance, dynamic web site authoring system
-
 =head1 VERSION
 
-version 1.54
+version 1.55
 
 =head1 SYNOPSIS
 
@@ -94,16 +91,17 @@ of Perl code (say, to pull records from a database). They can also
 call other components, cache results for later reuse, and perform all
 the tricks you expect from a regular Perl program.
 
+=encoding UTF-8
+
 =head1 WAIT - HAVE YOU SEEN MASON 2?
 
 Version 1 of Mason (this distribution) -- has been around since 1998, is in
 wide use, and is very stable. However it has not changed much in years and
 is no longer actively developed.
 
-Version 2 of Mason -- L<Mason|Mason> -- was released in February of 2011.
-It is being very actively developed and has a much more modern
-architecture. If you are just starting out, we recommend you give Mason 2 a
-try.
+Version 2 of Mason -- L<Mason> -- was released in February of 2011. It is more
+actively developed and has a much more modern architecture. If you are just
+starting out, we recommend you give Mason 2 a try.
 
 For a summary of differences between Mason 1 and 2 see
 
@@ -203,15 +201,6 @@ Bugs and feature requests will be tracked at RT:
     http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Mason
     bug-html-mason@rt.cpan.org
 
-The latest source code can be browsed and fetched at:
-
-    http://github.com/jonswar/perl-html-mason/tree/master
-    git clone git://github.com/jonswar/perl-html-mason.git
-
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
 =head1 AUTHORS
 
 =over 4
@@ -230,9 +219,41 @@ Ken Williams <ken@mathforum.org>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords Ævar Arnfjörð Bjarmason Alex Vandiver John Williams Kevin Falcone Patrick Kane Ricardo Signes
+
+=over 4
+
+=item *
+
+Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+
+=item *
+
+Alex Vandiver <alex@chmrr.net>
+
+=item *
+
+John Williams <jwilliams@cpan.org>
+
+=item *
+
+Kevin Falcone <falcone@bestpractical.com>
+
+=item *
+
+Patrick Kane <modus-cpan@pr.es.to>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Jonathan Swartz.
+This software is copyright (c) 1998 - 2014 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
