@@ -3,10 +3,7 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::Compiler;
-{
-  $HTML::Mason::Compiler::VERSION = '1.54';
-}
-
+$HTML::Mason::Compiler::VERSION = '1.55';
 use strict;
 use warnings;
 use Data::Dumper;
@@ -713,16 +710,10 @@ sub HTML::Mason::Parser::new
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::Compiler - Compile Mason component source
 
-=head1 VERSION
-
-version 1.54
-
 =head1 SYNOPSIS
 
   package My::Funky::Compiler;
@@ -992,33 +983,4 @@ We recommend that any parameters you add to Compiler be read-only,
 because the compiler object_id is only computed once on creation
 and would not reflect any changes to Lexer parameters.
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
