@@ -3,10 +3,7 @@
 # it under the same terms as Perl itself.
 
 package HTML::Mason::Compiler::ToObject;
-{
-  $HTML::Mason::Compiler::ToObject::VERSION = '1.54';
-}
-
+$HTML::Mason::Compiler::ToObject::VERSION = '1.55';
 use strict;
 use warnings;
 
@@ -641,16 +638,10 @@ sub _declared_args
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::Compiler::ToObject - A Compiler subclass that generates Mason object code
 
-=head1 VERSION
-
-version 1.54
-
 =head1 SYNOPSIS
 
   my $compiler = HTML::Mason::Compiler::ToObject->new;
@@ -758,33 +749,4 @@ override the class into which the component is compiled.
 
 =back
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
