@@ -3,10 +3,7 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::Component;
-{
-  $HTML::Mason::Component::VERSION = '1.54';
-}
-
+$HTML::Mason::Component::VERSION = '1.55';
 use strict;
 use warnings;
 use File::Spec;
@@ -392,16 +389,10 @@ sub logger {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::Component - Mason Component Class
 
-=head1 VERSION
-
-version 1.54
-
 =head1 SYNOPSIS
 
     my $comp1 = $m->current_comp;
@@ -644,33 +635,4 @@ Returns the directory of the source filename for this component.
 
 =back
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
