@@ -3,10 +3,7 @@
 # it under the same terms as Perl itself.
 
 package HTML::Mason::Component::Subcomponent;
-{
-  $HTML::Mason::Component::Subcomponent::VERSION = '1.54';
-}
-
+$HTML::Mason::Component::Subcomponent::VERSION = '1.55';
 use strict;
 use warnings;
 
@@ -53,16 +50,10 @@ sub title { return $_[0]->owner->title . ":" . $_[0]->name }
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::Component::Subcomponent - Mason Subcomponent Class
 
-=head1 VERSION
-
-version 1.54
-
 =head1 DESCRIPTION
 
 This is a subclass of
@@ -92,33 +83,4 @@ was defined.
 
 =back
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
