@@ -7,10 +7,7 @@
 #
 
 package HTML::Mason::Escapes;
-{
-  $HTML::Mason::Escapes::VERSION = '1.54';
-}
-
+$HTML::Mason::Escapes::VERSION = '1.55';
 use strict;
 use warnings;
 
@@ -47,16 +44,10 @@ sub url_escape
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::Escapes - Functions to escape text for Mason
 
-=head1 VERSION
-
-version 1.54
-
 =head1 DESCRIPTION
 
 This module contains functions for implementing Mason's L<substitution
@@ -105,33 +96,4 @@ details.
 
 =back
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
