@@ -1,3 +1,5 @@
+package HTML::Mason::FakeApache;
+$HTML::Mason::FakeApache::VERSION = '1.55';
 use strict;
 use warnings;
 
@@ -7,10 +9,6 @@ use warnings;
 # the CPAN indexer doesn't pick it up, which would be ugly.
 BEGIN { eval "package Apache" }
 
-package HTML::Mason::FakeApache;
-{
-  $HTML::Mason::FakeApache::VERSION = '1.54';
-}
 @HTML::Mason::FakeApache::ISA = qw(Apache);
 # Analogous to Apache request object $r (but not an actual Apache subclass)
 # In the future we'll probably want to switch this to Apache::Fake or similar
@@ -317,9 +315,7 @@ sub params {
 
 ###########################################################
 package HTML::Mason::FakeTable;
-{
-  $HTML::Mason::FakeTable::VERSION = '1.54';
-}
+$HTML::Mason::FakeTable::VERSION = '1.55';
 # Analogous to Apache::Table.
 use strict;
 use warnings;
@@ -374,9 +370,7 @@ sub do {
 
 ###########################################################
 package HTML::Mason::FakeTableHash;
-{
-  $HTML::Mason::FakeTableHash::VERSION = '1.54';
-}
+$HTML::Mason::FakeTableHash::VERSION = '1.55';
 # Used by HTML::Mason::FakeTable.
 use strict;
 use warnings;
@@ -479,16 +473,10 @@ sub _map_header_key_to_cgi_key {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::FakeApache - An Apache object emulator for use with Mason
 
-=head1 VERSION
-
-version 1.54
-
 =head1 SYNOPSIS
 
 See L<HTML::Mason::CGIHandler|HTML::Mason::CGIHandler>.
@@ -497,33 +485,4 @@ See L<HTML::Mason::CGIHandler|HTML::Mason::CGIHandler>.
 
 This class's API is documented in L<HTML::Mason::CGIHandler|HTML::Mason::CGIHandler>.
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
