@@ -1,8 +1,5 @@
 package HTML::Mason::Tests;
-{
-  $HTML::Mason::Tests::VERSION = '1.54';
-}
-
+$HTML::Mason::Tests::VERSION = '1.55';
 use strict;
 use warnings;
 
@@ -681,16 +678,10 @@ sub _cleanup
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::Tests - Test harness for testing Mason
 
-=head1 VERSION
-
-version 1.54
-
 =head1 SYNOPSIS
 
  use HTML::Mason::Tests;
@@ -969,33 +960,4 @@ that overrides the _make_interp method to use your subclass:
               %interp_params );
     }
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
