@@ -8,10 +8,7 @@
 #
 
 package HTML::Mason::Utils;
-{
-  $HTML::Mason::Utils::VERSION = '1.54';
-}
-
+$HTML::Mason::Utils::VERSION = '1.55';
 use HTML::Mason::Tools qw(compress_path);
 use strict;
 use warnings;
@@ -45,6 +42,7 @@ sub cgi_request_args
 
     foreach my $key ( map { $q->$_() } @methods ) {
         next if exists $args{$key};
+        local $CGI::LIST_CONTEXT_WARN = 0;
         my @values = map { $q->$_($key) } @methods;
         $args{$key} = @values == 1 ? $values[0] : \@values;
     }
@@ -57,16 +55,10 @@ sub cgi_request_args
 
 __END__
 
-=pod
-
 =head1 NAME
 
 HTML::Mason::Utils - Publicly available functions useful outside of Mason
 
-=head1 VERSION
-
-version 1.54
-
 =head1 DESCRIPTION
 
 The functions in this module are useful when you need to interface
@@ -98,33 +90,5 @@ references.
 
 =back
 
-=head1 SEE ALSO
-
-L<Mason|Mason>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Dave Rolsky <autarch@urth.org>
-
-=item *
-
-Ken Williams <ken@mathforum.org>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Jonathan Swartz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
